#
# spec file for package apache-commons-logging
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2000-2007, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define base_name  logging
%define short_name commons-%{base_name}
%bcond_with java_bootstrap
Name:           apache-%{short_name}
Version:        1.1.3
Release:        12.3
Summary:        Apache Commons Logging
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://commons.apache.org/%{base_name}
Source0:        http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz.asc
Source2:        apache-commons-logging.keyring
Source3:        http://mirrors.ibiblio.org/pub/mirrors/maven2/%{short_name}/%{short_name}-api/1.1/%{short_name}-api-1.1.pom
Patch0:         commons-logging-1.1.3-src-junit.diff
BuildRequires:  ant
BuildRequires:  apache-commons-parent
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  javapackages-tools
BuildRequires:  junit
BuildRequires:  log4j-mini >= 1.2
BuildRequires:  servletapi5
Requires:       java >= 1.6.0
Requires:       javapackages-tools
Requires(post): javapackages-tools
Requires(postun): javapackages-tools
Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       %{short_name} = %{version}-%{release}
Obsoletes:      %{short_name} < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if !%{with java_bootstrap}
BuildRequires:  ant-junit
%endif

%description
The commons-logging package provides a simple, component oriented
interface (org.apache.commons.logging.Log) together with wrappers for
logging systems. The user can choose at runtime which system they want
to use. In addition, a small number of basic implementations are
provided to allow users to use the package standalone.
commons-logging was heavily influenced by Avalon's Logkit and Log4J. The
commons-logging abstraction is meant to minimize the differences between
the two, and to allow a developer to not tie himself to a particular
logging implementation.

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1

# Sent upstream https://issues.apache.org/jira/browse/LOGGING-143
%pom_remove_dep :avalon-framework
%pom_add_dep avalon-framework:avalon-framework-api:4.3
%pom_add_dep avalon-framework:avalon-framework-impl:4.3:test

sed -i 's/\r//' RELEASE-NOTES.txt LICENSE.txt

#FIXME
rm ./src/test/java/org/apache/commons/logging/servlet/BasicServletTestCase.java

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

export CLASSPATH=$(build-classpath \
                   plexus/ \
                   junit \
                  ):target/classes:target/test-classes
ant -Dmaven.mode.offline=true -Dlog4j12.jar=%{_javadir}/log4j.jar dist \
    -lib %{_javadir}

%install
# jars
install -d -m 755 %{buildroot}%{_javadir}
install -p -m 644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
install -p -m 644 target/%{short_name}-api-%{version}.jar %{buildroot}%{_javadir}/%{name}-api.jar
install -p -m 644 target/%{short_name}-adapters-%{version}.jar %{buildroot}%{_javadir}/%{name}-adapters.jar

pushd %{buildroot}%{_javadir}
for jar in %{name}*; do
    ln -sf ${jar} `echo $jar| sed "s|apache-||g"`
done
popd

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}/%{_mavenpomdir}/JPP-%{short_name}.pom
install -pm 644 %{SOURCE3} %{buildroot}/%{_mavenpomdir}/JPP-%{short_name}-api.pom

%add_maven_depmap JPP-%{short_name}.pom %{short_name}.jar -a "org.apache.commons:commons-logging"
%add_maven_depmap JPP-%{short_name}-api.pom %{short_name}-api.jar -a "org.apache.commons:commons-logging-api"

%files
%defattr(0644,root,root,0755)
%doc PROPOSAL.html LICENSE.txt RELEASE-NOTES.txt NOTICE.txt
%{_javadir}/*
%{_mavenpomdir}/JPP-%{short_name}.pom
%{_mavenpomdir}/JPP-%{short_name}-api.pom
%config %{_mavendepmapfragdir}/*

%changelog
* Wed Mar 25 2015 tchvatal@suse.com
- Drop maven conditionals that were never triggered.
* Wed Mar 25 2015 tchvatal@suse.com
- Drop gpg offline and rely on service
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar  4 2015 tchvatal@suse.com
- Use log4j-mini to hopefully avoid build-cycle
* Fri Feb 20 2015 dmacvicar@suse.de
- add the log4j adapter to commons-logging-adapters
  (bnc#918852)
* Tue Aug 12 2014 lnussel@suse.de
- add bcond java_bootstrap to build without unit tests
  (commons-logging-1.1.3-src-junit.diff)
* Fri Jun 27 2014 tchvatal@suse.com
- Provides obsoletes to be versioned
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Aug 27 2013 mvyskocil@suse.com
- update to 1.1.3 (bugfix release)
  see http://commons.apache.org/proper/commons-logging/changes-report.html
  or RELEASE-NOTES.txt for details
- add gpg verification
- use new add_maven_depmap from javapackages-tools
- dropped unecessary patches/sources
  * build.xml.patch
  * commons-logging-eclipse-manifest.patch
  * commons-logging-maven-release-plugin.patch
  * and commons-logging.depmap
* Mon Apr  2 2012 mvyskocil@suse.cz
- provide commons-logging
* Tue Feb 28 2012 mvyskocil@suse.cz
- fix build cycle, do not require avalon-* for build and use servletapi5
  instead of tomcat6 package
* Wed Feb  8 2012 mvyskocil@suse.cz
- rename to apache-commons-logging to follow jpackage and Fedora
- update to 1.1.1 (bugfix release)
  * usable under security policy (catches SecurityException)
  * show content of chained exceptions
  * fix unit tests on linux an java6
  * provide maven2 pom file
  * fix thread-safety bug
* Sat Aug 27 2011 andrea.turrini@gmail.com
- fixed typos in jakarta-commons-logging.spec
* Wed Jul 16 2008 coolo@suse.de
- trying to reduce build requires
* Tue May  8 2007 kesselborn@suse.de
- remove avalon references ... avalon is dropped and support for it hence not needed
* Mon Sep 25 2006 skh@suse.de
- fix BuildRequires
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 1.0.4 from JPackage.org
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires of javadoc subpackage
* Sun Sep  5 2004 skh@suse.de
- Initial package created with version 1.0.4 (JPackage 1.5)
